searchData={"items":[{"type":"module","title":"WsClient","doc":"WsClient\nA web socket client that uses websocat via a Port.\nIn case of a crash of websocat it will be restarted\nand submit the same commands as before to get back\nto the state before the crash.","ref":"WsClient.html"},{"type":"function","title":"WsClient.callback/2","doc":"Sets the callback function that gets called with the\nreceived data from the connected web socket.","ref":"WsClient.html#callback/2"},{"type":"function","title":"Examples - WsClient.callback/2","doc":"You could use the Phoenix PubSub system to handle the data.\n\n\n    defp cb(json) do\n      with {:ok, data} <- JSON.decode(json |> to_string) do\n        Phoenix.PubSub.broadcast!(Project.PubSub, \"topic\", data)\n      else\n        err -> IO.inspect(err)\n      end\n    end\n\n    WsClient.callback(DocuClient, cb)\n\nIt is also possible to change the callback at runtime.\n\n    iex> cb = fn data -> data |> IO.inspect end\n    # \n    iex> WsClient.callback(DocuClient, cb)\n    :ok","ref":"WsClient.html#callback/2-examples"},{"type":"function","title":"WsClient.connect/2","doc":"Starts `websocat` and connect to the given URL.\n\nReturns `:ok` or `{:error, \"Already connected\"}`.","ref":"WsClient.html#connect/2"},{"type":"function","title":"Examples - WsClient.connect/2","doc":"iex> WsClient.connect(DocuClient, \"wss://echo.websocket.org\")\n    {:error, \"Already connected\"}\n    iex> WsClient.disconnect(DocuClient)\n    :ok\n    iex> WsClient.connect(DocuClient, \"wss://echo.websocket.org\")\n    :ok","ref":"WsClient.html#connect/2-examples"},{"type":"function","title":"WsClient.disconnect/1","doc":"Disconnects and stops the underlying `websocat` connection and application.\nReturns `:ok`.","ref":"WsClient.html#disconnect/1"},{"type":"function","title":"Examples - WsClient.disconnect/1","doc":"iex> WsClient.disconnect(DocuClient)\n    :ok","ref":"WsClient.html#disconnect/1-examples"},{"type":"function","title":"WsClient.send/2","doc":"Sends a message to the connected web server via the client.\nThe server's response data will be used in the provided callback function.\n\nMake sure to include a newline '\\n' character to submit the request.\n\nReturns `:ok`.","ref":"WsClient.html#send/2"},{"type":"function","title":"Examples - WsClient.send/2","doc":"iex> WsClient.send(DocuClient, \"hello world\\n\")\n    :ok","ref":"WsClient.html#send/2-examples"},{"type":"module","title":"WsClient.Core","doc":"","ref":"WsClient.Core.html"},{"type":"function","title":"WsClient.Core.demonitor/1","doc":"","ref":"WsClient.Core.html#demonitor/1"},{"type":"function","title":"WsClient.Core.monitor/1","doc":"","ref":"WsClient.Core.html#monitor/1"},{"type":"function","title":"WsClient.Core.quit_client/1","doc":"","ref":"WsClient.Core.html#quit_client/1"},{"type":"function","title":"WsClient.Core.send/2","doc":"","ref":"WsClient.Core.html#send/2"},{"type":"function","title":"WsClient.Core.start_client/1","doc":"","ref":"WsClient.Core.html#start_client/1"},{"type":"module","title":"WsClient.Worker","doc":"","ref":"WsClient.Worker.html"},{"type":"function","title":"WsClient.Worker.callback/2","doc":"","ref":"WsClient.Worker.html#callback/2"},{"type":"function","title":"WsClient.Worker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"WsClient.Worker.html#child_spec/1"},{"type":"function","title":"WsClient.Worker.connect/2","doc":"","ref":"WsClient.Worker.html#connect/2"},{"type":"function","title":"WsClient.Worker.disconnect/1","doc":"","ref":"WsClient.Worker.html#disconnect/1"},{"type":"function","title":"WsClient.Worker.send/2","doc":"","ref":"WsClient.Worker.html#send/2"},{"type":"function","title":"WsClient.Worker.start_link/1","doc":"","ref":"WsClient.Worker.html#start_link/1"},{"type":"extras","title":"WsClient","doc":"# WsClient\n\nA websocket client that uses [websocat](https://github.com/vi/websocat) via a Port.\nIn case of a crash of `websocat` it will be restarted and submit the same commands as before to get back to the state before the crash.","ref":"readme.html"},{"type":"extras","title":"Dependencies - WsClient","doc":"* [websocat](https://github.com/vi/websocat)\n\nIf\n```elixir\niex> System.find_executable(\"websocat\")\n```\nreturns a valid path you are good to go!","ref":"readme.html#dependencies"},{"type":"extras","title":"Installation - WsClient","doc":"```elixir\ndef deps do\n  [\n    {:ws_client, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - WsClient","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Without a supervisor - WsClient","doc":"```elixir\n# create callback on how to handle the received data from the server\ncb = fn data -> data |> IO.inspect end\n# the server to connect to\nurl = \"wss://echo.websocket.org\"\n\n# start the worker (GenServer)\n{:ok, _} =\n  GenServer.start_link(WsClient.Worker, %{cb: cb, url: url, port: \"\", commands: []}, name: EchoWorker)\n\n# send from the client to the server, the callback defined above will handle the answer message.\nWsClient.send(TestWorker, \"hi\\n\")\n```","ref":"readme.html#without-a-supervisor"},{"type":"extras","title":"With a supervisor (single worker) - WsClient","doc":"```elixir\ndef start(_type, _args) do\n  children = [\n    {WsClient.Worker,\n     args: %{\n       cb: &IO.inspect/1,\n       url: \"wss://echo.websocket.org\",\n       port: \"\",\n       commands: []\n     },\n     name: EchoWorker}\n  ]\n\n  opts = [strategy: :one_for_one, name: Test.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```","ref":"readme.html#with-a-supervisor-single-worker"},{"type":"extras","title":"With a supervisor (and multiple workers) - WsClient","doc":"This may be useful in case you want to connect to multiple websocket endpoints at the same time.\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  children = [\n    Supervisor.child_spec(\n      {WsClient.Worker,\n       args: %{\n         cb: &IO.inspect/1,\n         url: \"wss://echo.websocket.org\",\n         port: \"\",\n         commands: []\n       },\n       name: FirstWorker},\n      id: :my_worker_1\n    ),\n    Supervisor.child_spec(\n      {WsClient.Worker,\n       args: %{\n         cb: &IO.inspect/1,\n         url: \"wss://echo.websocket.org\",\n         port: \"\",\n         commands: []\n       },\n       name: SecondWorker},\n      id: :my_worker_2\n    )\n  ]\n\n  opts = [strategy: :one_for_one, name: Test.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```","ref":"readme.html#with-a-supervisor-and-multiple-workers"},{"type":"extras","title":"Usage - WsClient","doc":"After the connection you can use\n```elixir\nWsClient.send(pid, message)\n```\nto send a message to the web server you are connected to, e.g.\n```elixir\nWsClient.send(TestWorker, \"hi\\n\")\n```\n\nTo change the handling callback at runtime use\n```elixir\nWsClient.callback(pid, fun)\n```\nExample with Elixir 1.18 and the new internal JSON function:\n```elixir\ncb = fn data -> JSON.decode(data) end\nWsClient.callback(Worker, cb)\n```\n\nTo close the port (will otherwise be handled automatically on exit of the GenServer)\n```elixir\nWsClient.disconnect(pid)\n```","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}